==> fastybird-redisdb-storage-plugin-0.6.0.tar.gz: fastybird-redisdb-storage-plugin-0.6.0/README.md <==
# FastyBird Redis DB storage plugin

[![Build Status](https://badgen.net/github/checks/FastyBird/redisdb-storage-plugin/master?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-storage-plugin/actions)
[![Licence](https://badgen.net/github/license/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-storage-plugin/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/redisdb-storage-plugin)

![PHP](https://badgen.net/packagist/php/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/redisdb-storage-plugin/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-storage-plugin)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-storage-plugin)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-redisdb-storage-plugin?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-redisdb-storage-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-storage-plugin/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-redisdb-storage-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-storage-plugin/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird Redis DB storage plugin?

This is a combined plugin for [Nette framework](https://nette.org) and [Python](https://www.python.org) which is
implementing [Redis](https://redis.io) state storage for [FastyBird](https://www.fastybird.com) IoT services

## Installation

### PHP based project:

The best way to install **fastybird/redisdb-storage-plugin** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/redisdb-storage-plugin
```

### Python based project:

The best way to install **fastybird-redisdb-storage-plugin** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-redisdb-storage-plugin
```

## Documentation

Learn how to read & write states
in [documentation](https://github.com/FastyBird/redisdb-storage-plugin/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/FastyBird/redisdb-storage-plugin](https://github.com/FastyBird/redisdb-storage-plugin).

==> fastybird-redisdb-storage-plugin-0.10.0.tar.gz: fastybird-redisdb-storage-plugin-0.10.0/README.md <==
# FastyBird Redis DB storage plugin

[![Build Status](https://badgen.net/github/checks/FastyBird/redisdb-storage-plugin/master?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-storage-plugin/actions)
[![Licence](https://badgen.net/github/license/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-storage-plugin/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/redisdb-storage-plugin)

![PHP](https://badgen.net/packagist/php/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/redisdb-storage-plugin/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-storage-plugin)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/redisdb-storage-plugin?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-storage-plugin)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-redisdb-storage-plugin?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-redisdb-storage-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-storage-plugin/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-redisdb-storage-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-storage-plugin/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird Redis DB storage plugin?

This is a combined plugin for [FastyBird](https://www.fastybird.com) ecosystem which is
implementing [Redis](https://redis.io) state storage

## Installation

### PHP based project:

The best way to install **fastybird/redisdb-storage-plugin** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/redisdb-storage-plugin
```

### Python based project:

The best way to install **fastybird-redisdb-storage-plugin** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-redisdb-storage-plugin
```

## Documentation

Learn how to read & write states
in [documentation](https://github.com/FastyBird/redisdb-storage-plugin/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/FastyBird/redisdb-storage-plugin](https://github.com/FastyBird/redisdb-storage-plugin).
